# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: accelbyte_cloud_py_codegen

"""Auto-generated package that contains models used by the AccelByte Cloud Iam Service."""

__version__ = "5.18.0"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .authentication_with_pla_4d2d24 import AuthenticationWithPlatformLinkV3
from .generate_token_by_new_h_af6555 import GenerateTokenByNewHeadlessAccountV3
from .get_country_location_v3 import GetCountryLocationV3
from .logout import Logout
from .platform_authentication_v3 import PlatformAuthenticationV3
from .request_game_token_code_07a103 import RequestGameTokenCodeResponseV3
from .request_game_token_response_v3 import RequestGameTokenResponseV3
from .user_authentication_v3 import UserAuthenticationV3
