# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: accelbyte_cloud_py_codegen

"""Auto-generated package that contains models used by the AccelByte Cloud Group Service."""

__version__ = "2.11.7"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .models_assign_role_to_member_request_v1 import ModelsAssignRoleToMemberRequestV1
from .models_create_group_configuration_request_v1 import (
    ModelsCreateGroupConfigurationRequestV1,
)
from .models_create_group_configuration_response_v1 import (
    ModelsCreateGroupConfigurationResponseV1,
)
from .models_create_member_role_request_v1 import ModelsCreateMemberRoleRequestV1
from .models_create_member_role_response_v1 import ModelsCreateMemberRoleResponseV1
from .models_get_group_configuration_response_v1 import (
    ModelsGetGroupConfigurationResponseV1,
)
from .models_get_group_member_list_response_v1 import ModelsGetGroupMemberListResponseV1
from .models_get_groups_list_response_v1 import ModelsGetGroupsListResponseV1
from .models_get_member_requests_list_response_v1 import (
    ModelsGetMemberRequestsListResponseV1,
)
from .models_get_member_role_response_v1 import ModelsGetMemberRoleResponseV1
from .models_get_member_roles_list_response_v1 import ModelsGetMemberRolesListResponseV1
from .models_get_user_group_information_response_v1 import (
    ModelsGetUserGroupInformationResponseV1,
)
from .models_group_member import ModelsGroupMember
from .models_group_response_v1 import ModelsGroupResponseV1
from .models_group_rule import ModelsGroupRule
from .models_group_rule_group_custom_rule import ModelsGroupRuleGroupCustomRule
from .models_join_group_response_v1 import ModelsJoinGroupResponseV1
from .models_kick_group_member_response_v1 import ModelsKickGroupMemberResponseV1
from .models_leave_group_response_v1 import ModelsLeaveGroupResponseV1
from .models_list_configuration_response_v1 import ModelsListConfigurationResponseV1
from .models_member_request_group_response_v1 import ModelsMemberRequestGroupResponseV1
from .models_member_request_response_v1 import ModelsMemberRequestResponseV1
from .models_pagination import ModelsPagination
from .models_public_create_new_group_request_v1 import (
    ModelsPublicCreateNewGroupRequestV1,
)
from .models_remove_role_from_member_request_v1 import (
    ModelsRemoveRoleFromMemberRequestV1,
)
from .models_role_permission import ModelsRolePermission
from .models_rule import ModelsRule
from .models_rule_information import ModelsRuleInformation
from .models_rule_information import (
    RuleCriteriaEnum as ModelsRuleInformationRuleCriteriaEnum,
)
from .models_update_group_configuration_global_rules_request_v1 import (
    ModelsUpdateGroupConfigurationGlobalRulesRequestV1,
)
from .models_update_group_configuration_request_v1 import (
    ModelsUpdateGroupConfigurationRequestV1,
)
from .models_update_group_configuration_response_v1 import (
    ModelsUpdateGroupConfigurationResponseV1,
)
from .models_update_group_custom_attributes_request_v1 import (
    ModelsUpdateGroupCustomAttributesRequestV1,
)
from .models_update_group_custom_rule_request_v1 import (
    ModelsUpdateGroupCustomRuleRequestV1,
)
from .models_update_group_predefined_rule_request_v1 import (
    ModelsUpdateGroupPredefinedRuleRequestV1,
)
from .models_update_group_request_v1 import ModelsUpdateGroupRequestV1
from .models_update_group_request_v1_custom_attributes import (
    ModelsUpdateGroupRequestV1CustomAttributes,
)
from .models_update_member_role_permissions_request_v1 import (
    ModelsUpdateMemberRolePermissionsRequestV1,
)
from .models_update_member_role_request_v1 import ModelsUpdateMemberRoleRequestV1
from .models_update_member_role_response_v1 import ModelsUpdateMemberRoleResponseV1
from .models_user_invitation_response_v1 import ModelsUserInvitationResponseV1
from .response_error_response import ResponseErrorResponse
