# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: accelbyte_cloud_py_codegen

"""Auto-generated package that contains models used by the Analytics Game Telemetry."""

__version__ = "1.10.0"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from ._gametelemetry_operations import (
    protected_get_playtime_game_telemetry_v1_protected_steam_ids_steam_id_playtime_get,
)
from ._gametelemetry_operations import (
    protected_get_playtime_game_telemetry_v1_protected_steam_ids_steam_id_playtime_get_async,
)
from ._gametelemetry_operations import (
    protected_save_events_game_telemetry_v1_protected_events_post,
)
from ._gametelemetry_operations import (
    protected_save_events_game_telemetry_v1_protected_events_post_async,
)
from ._gametelemetry_operations import (
    protected_update_playtime_game_telemetry_v1_protected_steam_ids_steam_id_playtime_playtime_put,
)
from ._gametelemetry_operations import (
    protected_update_playtime_game_telemetry_v1_protected_steam_ids_steam_id_playtime_playtime_put_async,
)

from ._operations import (
    get_events_game_telemetry_v1_admin_namespaces_namespace_events_get,
)
from ._operations import (
    get_events_game_telemetry_v1_admin_namespaces_namespace_events_get_async,
)
